#!/bin/sh
# test.sh -- run daflow test data sets
#
# Usage: test.sh [start [stop]]
#
#        where: start = starting test number
#                stop = ending test number (may be same as start)
#
# History: 96/04/07 kmflynn

# pathname
WrdA=/usr/opt/wrdapp

#*******************************************************************
#***** You should not need to modify anything below this line. *****
#*******************************************************************

# pathnames and other variables
  Prgm=$WrdA/daflow1.2
  Data=$Prgm/data
  Chck=$Prgm/test
  Anne=$WrdA/annie2.2

  exec 2>&1                                # stderr shows up in .out file
  Start=${1-1}                             # by default, start at 1
  Stop=${2-4}                              # by default, stop at 4
                                           # 1 - Problem F1, steps 1 - 4
                                           # 2 - Problem F3, steps 1 - 4
                                           # 3 - Problem D1, steps 1 - 3
                                           # 4 - Problem W1

# begin test runs
  echo
  echo _________________________________________________________________
  echo " Begin processing daflow test runs $Start to $Stop"
  echo " daflow program from: $Prgm"
  echo "      test data from: $Data"
  echo `date`


  if [ $Start -le 1 -a $Stop -ge 1 ] ; then
#   run programs associated with test F1

#   step 1 - compute coefficients for area and width
    if [ -f test_F1.lg1 ] ; then rm test_F1.lg1 ; fi
    $Prgm/bin/cel < $Data/test_F1.cm1 | tee test_F1.lg1

#   step 2 - build the input file for daflow
    if [ -f test_F1.lg2 ] ; then rm test_F1.lg2 ; fi
    if [ -f test_F1.in2 ] ; then rm test_F1.in2 ; fi
    if [ -f flow.in ]     ; then rm flow.in     ; fi
    if [ -f bc ]          ; then rm bc          ; fi
    ln -s $Data/hinton.q bc
    $Prgm/bin/bdaflow < $Data/test_F1.cm2 | tee test_F1.lg2
    cp -p flow.in test_F1.in2

#   step 3 - compute average flow at the grids
    if [ -f test_F1.lg3 ] ; then rm test_F1.lg3 ; fi
    if [ -f test_F1.ot3 ] ; then rm test_F1.ot3 ; fi
    if [ -f test_F1.fl3 ] ; then rm test_F1.fl3 ; fi
    if [ -f flow.out ]    ; then rm flow.out    ; fi
    if [ -f bltm.flw ]    ; then rm bltm.flw    ; fi
    $Prgm/bin/daflow | tee test_F1.lg3
    cp -p bltm.flw test_F1.fl3
    cp -p flow.out test_F1.ot3

#   step 4 - plot the results
    if [ -f test_F1.lg4 ] ; then rm test_F1.lg4 ; fi
    if [ -f test_F1.pl4 ] ; then rm test_F1.pl4 ; fi
    if [ -f test_F1.ps4 ] ; then rm test_F1.ps4 ; fi
    if [ -f plt.out ]     ; then rm plt.out     ; fi
    if [ -f obs ]         ; then rm obs         ; fi
    ln -s $Data/thurmond.q obs
    $Prgm/bin/flwplt < $Data/test_F1.cm4 | tee test_F1.lg4
     cp -p plt.out test_F1.pl4

#   clean up
    for Fil in bc obs flow.in bltm.flw flow.out plt.out ; do
      if [ -f $Fil ] ; then rm $Fil ; fi
    done
  fi


  if [ "$Start" -le 2 -a "$Stop" -ge 2 ] ; then
#   run programs associated with test F3

#   step 1 - read adaps file unit.in (and optional stage discharge
#            rating table file rt) and output file out.
#            Note:  first time in unit.in must be 0.
    if [ -f test_F3.lg1 ] ; then rm test_F3.lg1 ; fi
    if [ -f test_F3.ot1 ] ; then rm test_F3.ot1 ; fi
    if [ -f unit.in ]     ; then rm unit.in     ; fi
    if [ -f rt ]          ; then rm rt          ; fi
    if [ -f out ]         ; then rm out         ; fi
    ln -s $Data/hinton.rt rt
    cp -p $Data/hinton.unt unit.in
    # first time in unit must be zero hours
    ed -s unit.in <<-E-O-T
	/---/+1 t /---/+1
	.-ls/30/00/
	w
	q
	E-O-T
    $Prgm/bin/unit < $Data/test_F3.cm1 | tee test_F3.lg1
    cp -p out test_F3.ot1

#   step 2 - interpolate data to an even interval
    if [ -f test_F3.lg2 ] ; then rm test_F3.lg2 ; fi
    if [ -f test_F3.bc2 ] ; then rm test_F3.bc2 ; fi
    if [ -f in ]          ; then rm in          ; fi
    if [ -f bc ]          ; then rm bc          ; fi
    mv out in
    $Prgm/bin/intrp < $Data/test_F3.cm2 | tee test_F3.lg2
    cp -p bc test_F3.bc2

#   step 3 - build input file for daflow
#            note:  changes made to flow.in from test 1
    if [ -f test_F3.lg3 ] ; then rm test_F3.lg3 ; fi
    if [ -f test_F3.in3 ] ; then rm test_F3.in3 ; fi
    if [ -f old ]         ; then rm old         ; fi
    if [ -f flow.in ]     ; then rm flow.in     ; fi
    cp $Data/test_F1.in2 old
    # change test id, time step, and Disch
    ed -s old <<-E-O-T
	/F1/s//F3/
	/312/s//168/
	g/2356/s//3860
	w
	q
	E-O-T
    $Prgm/bin/bdaflow < $Data/test_F3.cm3 | tee test_F3.lg3
    cp -p flow.in test_F3.in3

#   step 4 - compute average flow at the grids
    if [ -f test_F3.lg4 ] ; then rm test_F3.lg4 ; fi
    if [ -f test_F3.fl4 ] ; then rm test_F3.fl4 ; fi
    if [ -f test_F3.ot4 ] ; then rm test_F3.ot4 ; fi
    if [ -f flow.out ]    ; then rm flow.out    ; fi
    if [ -f bltm.flw ]    ; then rm bltm.flw    ; fi
    $Prgm/bin/daflow | tee test_F3.lg4
    cp -p bltm.flw test_F3.fl4
    cp -p flow.out test_F3.ot4

#   clean up
    for Fil in bc rt in old obs flow.in bltm.flw flow.out ; do
      if [ -f $Fil ] ; then rm $Fil ; fi
    done

  fi

  if [ $Start -le 3 -a $Stop -ge 3 ] ; then
#   run programs associated with test D1

#   step 1 - interpolate data to an even interval
#            note:  changes made for flow.in and out from test 2
    if [ -f test_D1.lg1 ] ; then rm test_D1.lg1 ; fi
    if [ -f test_D1.bc1 ] ; then rm test_D1.bc1 ; fi
    if [ -f in ]        ; then rm in        ; fi
    if [ -f bc ]        ; then rm bc        ; fi
    cp -p $Data/test_D1.in1 in
    $Prgm/bin/intrp < $Data/test_D1.cm1 | tee test_D1.lg1
    cp -p bc test_D1.bc1

#   step 2 - build the input file for daflow
    if [ -f test_D1.lg2 ] ; then rm test_D1.lg2 ; fi
    if [ -f test_D1.in2 ] ; then rm test_D1.in2 ; fi
    if [ -f flow.in   ] ; then rm flow.in   ; fi
    if [ -f old       ] ; then rm old       ; fi
    cp -p $Data/test_F3.in3 old
    ed -s old <<-E-O-T
	/F3/s//D1/
	/168/s//112/
	/1.000/s//0.250/
	/ 6 /s// 5 /
	/ 1 /d
	.-1
	/ 2 /s// 1 /
	/ 3 /s// 2 /
	/ 4 /s// 3 /
	/ 5 /s// 4 /
	/ 6 /s// 5 /
	g/3860. /s//9600. /
	w
	q
	E-O-T
    $Prgm/bin/bdaflow < $Data/test_D1.cm2 | tee test_D1.lg2
    cp -p flow.in test_D1.in2

#   Step 3 - compute average flow at the grids
    if [ -f test_D1.lg3 ] ; then rm test_D1.lg3 ; fi
    if [ -f test_D1.ot3 ] ; then rm test_D1.ot3 ; fi
    if [ -f test_D1.fl3 ] ; then rm test_D1.fl3 ; fi
    if [ -f bltm.flw  ] ; then rm bltm.flw  ; fi
    if [ -f flow.out  ] ; then rm flow.out  ; fi
    $Prgm/bin/daflow | tee test_D1.lg3
    cp -p bltm.flw test_D1.fl3
    cp -p flow.out test_D1.ot3

  fi

  if [ $Start -le 4 -a $Stop -ge 4 ] ; then
#   run programs associated with test W1

#   step 1 - get or build wdm file
    if [ -f $Data/test_W1.wdm ] ; then
#     copy existing wdm file from data directory
      echo " Copying test_W1.wdm from $Data"
      if [ -f test_W1.wdm ] ; then rm test_W1.wdm ; fi
      cp -p $Data/test_W1.wdm test_W1.wdm
    else
#     build wdm file
      echo " Building the test_W1.wdm file using annie"
      rm -f ERROR.FIL ANNIE.LOG
      ln -s $Data/test_W1.exp test_W1.exp
      $Anne/bin/annie <<-EOT
	@$Data/test_W1.cm1
	EOT
      rm -f ERROR.FIL ANNIE.LOG XPAD.DAT
      rm -f test_W1.exp
    fi

#   step 2 - run wdaflo with wdm file input and output
    if [ -f test_W1.lg2 ] ; then rm test_W1.lg2 ; fi
    if [ -f test_W1.ot2 ] ; then rm test_W1.ot2 ; fi
    if [ -f test_W1.fl2 ] ; then rm test_W1.fl2 ; fi
    if [ -f bltm.flw  ] ; then rm bltm.flw  ; fi
    if [ -f flow.out  ] ; then rm flow.out  ; fi
    cp -p $Data/test_W1.in2 flow.in
    $Prgm/bin/wdaflo | tee test_W1.lg2
    cp -p bltm.flw test_W1.fl2
    cp -p flow.out test_W1.ot2

#   step 3 - run wdaflo without wdm file
    if [ -f test_W1.lg3 ] ; then rm test_W1.lg3 ; fi
    if [ -f test_W1.ot3 ] ; then rm test_W1.ot3 ; fi
    if [ -f test_W1.fl3 ] ; then rm test_W1.fl3 ; fi
    if [ -f bltm.flw  ] ; then rm bltm.flw  ; fi
    if [ -f flow.out  ] ; then rm flow.out  ; fi
    cp -p $Data/test_W1.in3 flow.in
    $Prgm/bin/wdaflo | tee test_W1.lg3
    cp -p bltm.flw test_W1.fl3
    cp -p flow.out test_W1.ot3

  fi

  echo
  echo
  echo _________________________________________________________________
  echo "Completed daflow test runs $Start to $Stop"
  echo
# check output against original output in data directory
  $Chck/check.sh $Data

# end of shell
